@@ -49,17 +49,22 @@ class Utilities:
     def safe_div(x, y):
         return 0 if y == 0 else x / y
 
+    def safe_div_int(self, x, y):
+        return int(self.safe_div(x, y))
+
     def safe_div_round(self, x, y, decimals=2):
         return round(self.safe_div(x, y), decimals)
 
-    @staticmethod
-    def safe_div_int(x, y):
-        return int(0 if y == 0 else x / y)
-
     @staticmethod
     def get_distance(p0, p1):
         return sqrt((p0[0] - p1[0]) ** 2 + (p0[1] - p1[1]) ** 2)
 
+    def get_distance_int(self, p0, p1):
+        return int(self.get_distance(p0, p1))
+
+    def get_distance_rounded(self, p0, p1, decimals=0):
+        return round(self.get_distance(p0, p1), decimals)
+
     ##########################
     # Process Functions
     ##########################
@@ -137,6 +142,19 @@ class Utilities:
     ##########################
     # Utility Functions
     ##########################
+    @staticmethod
+    def find(input_, string, options=any, contains=True):
+        if isinstance(input_, list):
+            if contains:
+                return options(item in string for item in input_)
+            else:
+                return options(item not in string for item in input_)
+        else:
+            if contains:
+                return string in input_
+            else:
+                return input_ not in string
+
     @staticmethod
     def pause(milliseconds: int):
         sleep(milliseconds * 0.001)
@@ -189,3 +207,11 @@ class Utilities:
         cv2.imshow(window_name, image)
         if cv2.waitKey(delay) & 0xFF == ord(stop_key):
             cv2.destroyAllWindows()
+
+    # def timeout(self, key, ms):
+    #     if key in self.timeouts:
+    #         return self.timeouts[key].timeout(ms)
+    #
+    #     else:
+    #         self.timeouts[key] = ProcessTime()
+    #         return False
